@@ -21,9 +21,6 @@
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xatom.h>
-#ifdef USE_XFT
-#include <X11/Xft/Xft.h>
-#endif
 
 #include "structs.h"
 #include "base_client.h"
@@ -44,6 +41,9 @@ void select_client_init(client *c);
 void select_client_reparent(client *c);
 void select_client_redraw(client *c, Bool use_cache);
 
+void select_client_event_loop( Client *c, struct list_item *button_item_cur );
+
+
 #endif
 
 
